@@ -16,5 +16,12 @@ from pyvalueobjects.numbers.positive_int import PositiveInt
 from pyvalueobjects.numbers.negative_int import NegativeInt
 from pyvalueobjects.numbers.nullable_negative_int import NullableNegativeInt
 from pyvalueobjects.numbers.positive_or_zero_int import PositiveOrZeroInt
+from pyvalueobjects.numbers.nullable_positive_or_zero_int import NullablePositiveOrZeroInt
 from pyvalueobjects.numbers.negative_or_zero_int import NegativeOrZeroInt
 from pyvalueobjects.numbers.nullable_negative_or_zero_int import NullableNegativeOrZeroInt
+
+# -----------------------------
+# ---------- Strings ----------
+# -----------------------------
+
+from pyvalueobjects.strings.string import String
